@@ -4,12 +4,15 @@
 """
 
 import io
+import logging
 
 import numpy as np
 import pandas as pd
 
 from pandastools.utils import dataimport
 
+logger = logging.getLogger(__name__)
+
 
 @pd.api.extensions.register_dataframe_accessor("pt")
 class DataFrameAccessor(object):
@@ -19,9 +22,9 @@ class DataFrameAccessor(object):
     def iat(self, start=None, stop=None, step=1):
         return self._obj.iloc[start:stop:step]
 
-    def get_info(self) -> str:
+    def get_info(self, null_counts: bool = True) -> str:
         buf = io.StringIO()
-        self._obj.info(buf=buf, null_counts=True)
+        self._obj.info(buf=buf, null_counts=null_counts)
         return buf.getvalue()
 
     def uniquify_columns(self):
@@ -47,21 +50,39 @@ class DataFrameAccessor(object):
                            .apply(lambda x: x.astype(new_dtype)))
         return self._obj
 
-    def split(self, thresh, colname, extra_rows):
+    def split(self, thresh, colname, extra_rows: int = 0):
         """
         split dataframe into separate chunks based on supplied criteria
         """
         # split processes based on bool value (just process when no bool split)
-        self._obj = self._obj.drop("secs", errors="ignore", axis=1)
-        array = np.full((len(self._obj.index),), np.nan)
-        self._obj["process_num"] = pd.Categorical(array)
-        ds = dataimport.add_transition_info(ds=self._obj,
+        ds = self._obj.drop("secs", errors="ignore", axis=1)
+        array = np.full((len(ds.index),), np.nan)
+        ds["process_num"] = pd.Categorical(array)
+        ds = dataimport.add_transition_info(ds=ds,
                                             colname=colname,
                                             threshold=thresh,
                                             extra_rows=extra_rows)
         return ds
 
+    def index_to_secs(self):
+        if self._obj.empty:
+            logger.debug("index_to_secs failed. Dataframe empty")
+            return self._obj
+        elif isinstance(self._obj.index, pd.DatetimeIndex):
+            secs = self._obj.index.astype(int) / 1_000_000_000
+            ds = self._obj.assign(secs=secs - secs[0]).set_index("secs", drop=True)
+            return ds
+        else:
+            logger.debug("index_to_secs failed. No DateTimeIndex")
+            return self._obj
+
+    def cleanup(self):
+        ds = self._obj.infer_objects()
+        cols = ds.select_dtypes(["object"]).columns
+        ds[cols] = ds.select_dtypes(["object"]).apply(lambda x: x.astype("category"))
+        return ds
+
 
 if __name__ == "__main__":
     df = pd.DataFrame()
-    df.pp.uniquify_columns()
+    df.pt.uniquify_columns()
